Crate agent_shell_parser

Crate agent_shell_parser 

Modules

guard

Structs

PreToolUseInput
WorktreeCreateInput
WorktreeRemoveInput

Enums

Error

Functions

find_command_position
Returns the index of the first token that is the actual command being invoked, skipping leading env-var assignments (FOO=bar).
is_jj_colocated
jj_version
parse_input
require_jj_version