resolve_command_with

Function resolve_command_with 

pub fn resolve_command_with(
    words: &[String],
    config: &CommandConfig,
) -> ResolvedCommand
Resolve a command through the indirection layer using a custom config.

Same as resolve_command but accepts caller-provided CommandConfig, allowing consumers to extend or replace the default command knowledge.