pub struct SubstitutionSpan {
pub start: usize,
pub end: usize,
pub pipeline: ParsedPipeline,
}Expand description
A command substitution’s position and recursively-parsed contents.
Fields
start: usizeByte offset of the substitution start within the parent’s text.
For substitutions on a ShellSegment, this indexes into
segment.command. For structural substitutions on a
ParsedPipeline, this is relative to the source text passed
to [parse_with_substitutions] at this recursion level (for
nested pipelines, that is the inner text of the parent
substitution, not the top-level command string).
end: usizeByte offset past the end of the substitution.
pipeline: ParsedPipelineThe recursively-parsed inner pipeline.