Module path

Module path 

Functions

effective_cwd
Determine the effective working directory for each git command in a pipeline.
extract_cd_target
Return the first non-flag, non-cd argument from a cd command’s word list.
extract_git_c_path
Extract the path from git -C <path> if present.
resolve_path
Resolve a cd target path against a base (current working) directory.