Functions
- effective_
cwd - Determine the effective working directory for each git command in a pipeline.
- extract_
cd_ target - Return the first non-flag, non-
cdargument from acdcommand’s word list. - extract_
git_ c_ path - Extract the path from
git -C <path>if present. - resolve_
path - Resolve a cd target path against a base (current working) directory.